# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_macd.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/daily_analytics/v1/daily_macd.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xff\x01\n\x10\x44\x61ilyMacdRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x12\n\x04long\x18\x03 \x01(\x05R\x04long\x12\x14\n\x05short\x18\x04 \x01(\x05R\x05short\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\"e\n\x11\x44\x61ilyMacdResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.daily_analytics.v1.DailyMacdDataR\x04\x64\x61ta\"\x8a\x01\n\rDailyMacdData\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x12\n\x04macd\x18\x03 \x01(\x01R\x04macd\x12\x14\n\x05short\x18\x04 \x01(\x01R\x05short\x12\x12\n\x04long\x18\x05 \x01(\x01R\x04long2\xc5\x01\n\x10\x44\x61ilyMacdService\x12\xb0\x01\n\tDailyMacd\x12?.systemathics.apis.services.daily_analytics.v1.DailyMacdRequest\x1a@.systemathics.apis.services.daily_analytics.v1.DailyMacdResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/daily-analytics/macdB\x98\x02\n1com.systemathics.apis.services.daily_analytics.v1B\x0e\x44\x61ilyMacdProtoP\x01\xa2\x02\x04SASD\xaa\x02,Systemathics.Apis.Services.DailyAnalytics.V1\xca\x02,Systemathics\\Apis\\Services\\DailyAnalytics\\V1\xe2\x02\x38Systemathics\\Apis\\Services\\DailyAnalytics\\V1\\GPBMetadata\xea\x02\x30Systemathics::Apis::Services::DailyAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.systemathics.apis.services.daily_analytics.v1B\016DailyMacdProtoP\001\242\002\004SASD\252\002,Systemathics.Apis.Services.DailyAnalytics.V1\312\002,Systemathics\\Apis\\Services\\DailyAnalytics\\V1\342\0028Systemathics\\Apis\\Services\\DailyAnalytics\\V1\\GPBMetadata\352\0020Systemathics::Apis::Services::DailyAnalytics::V1'
  _globals['_DAILYMACDSERVICE'].methods_by_name['DailyMacd']._options = None
  _globals['_DAILYMACDSERVICE'].methods_by_name['DailyMacd']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/daily-analytics/macd'
  _globals['_DAILYMACDREQUEST']._serialized_start=273
  _globals['_DAILYMACDREQUEST']._serialized_end=528
  _globals['_DAILYMACDRESPONSE']._serialized_start=530
  _globals['_DAILYMACDRESPONSE']._serialized_end=631
  _globals['_DAILYMACDDATA']._serialized_start=634
  _globals['_DAILYMACDDATA']._serialized_end=772
  _globals['_DAILYMACDSERVICE']._serialized_start=775
  _globals['_DAILYMACDSERVICE']._serialized_end=972
# @@protoc_insertion_point(module_scope)
